/*
   microMVC Java Port by Donald Stinchfield <donald.stinchfield@microMVC.org>, et al.
   microMVC - Copyright(c) 2006-08 Futurescale, Inc., Some rights reserved.
   Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

package com.btc.micromvc.interfaces;

/**
 * The interface definition for a microMVC Model.
 * 
 * <P>
 * In microMVC, <code>IModel</code> implementors provide access to
 * <code>IModelService</code> objects by named lookup.
 * </P>
 * 
 * <P>
 * An <code>IModel</code> assumes these responsibilities:
 * </P>
 * 
 * <UL>
 * <LI>Maintain a cache of <code>IModelService</code> instances</LI>
 * <LI>Provide methods for registering, retrieving, and removing
 * <code>IModelService</code> instances</LI>
 * </UL>
 */
public interface IModel
{

	/**
	 * Register an <code>IModelService</code> instance with the <code>Model</code>.
	 * 
	 * @param ModelService
	 *            an object reference to be held by the <code>Model</code>.
	 */
	public void registerModelService( IModelService ModelService );

	/**
	 * Retrieve an <code>IModelService</code> instance from the Model.
	 * 
	 * @param ModelService
	 * @return the <code>IModelService</code> instance previously registered with the
	 *         given <code>ModelServiceName</code>.
	 */
	public IModelService retrieveModelService( String ModelService );

	/**
	 * Remove an <code>IModelService</code> instance from the Model.
	 * 
	 * @param ModelService
	 *            name of the <code>IModelService</code> instance to be removed.
	 */
	public IModelService removeModelService( String ModelService );
}
