/*
   microMVC Java Port by Donald Stinchfield <donald.stinchfield@microMVC.org>, et al.
   microMVC - Copyright(c) 2006-08 Futurescale, Inc., Some rights reserved.
   Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

package com.btc.micromvc.interfaces;

/**
 * The interface definition for a microMVC ModelService.
 * 
 * <P>
 * In microMVC, <code>IModelService</code> implementors assume these responsibilities:
 * </P>
 * <UL>
 * <LI>Implement a common method which returns the name of the ModelService.</LI>
 * </UL>
 * <P>
 * Additionally, <code>IModelService</code>s typically:
 * </P>
 * <UL>
 * <LI>Maintain references to one or more pieces of model data.</LI>
 * <LI>Provide methods for manipulating that data.</LI>
 * <LI>Generate <code>INotifications</code> when their model data changes.</LI>
 * <LI>Expose their name as a <code>public static const</code> called <code>NAME</code>, if they are not instantiated multiple times.</LI>
 * <LI>Encapsulate interaction with local or remote services used to fetch and
 * persist model data.</LI>
 * </UL>
 */
public interface IModelService
{

	/**
	 * Get the ModelService name
	 * 
	 * @return the ModelService instance name
	 */
	public String getModelServiceName( );
	
	/**
	 * Set the data object
	 * 
	 * @param data the data object
	 */
	public void setData( Object data );
	
	/**
	 * Get the data object
	 * 
	 * @return the data as type Object
	 */
	public Object getData(); 

}
