/*
   microMVC Java Port by Donald Stinchfield <donald.stinchfield@microMVC.org>, et al.
   microMVC - Copyright(c) 2006-08 Futurescale, Inc., Some rights reserved.
   Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

package com.btc.micromvc.patterns.command;

import com.btc.micromvc.interfaces.IControllerCmd;
import com.btc.micromvc.interfaces.INotification;
import com.btc.micromvc.patterns.observer.Notifier;

/**
 * A base <code>IControllerCmd</code> implementation.
 * 
 * <P>
 * Your subclass should override the <code>execute</code> method where your
 * business logic will handle the <code>INotification</code>.
 * </P>
 * 
 * @see com.btc.micromvc.core.controller.Controller Controller
 * @see com.btc.micromvc.patterns.observer.Notification Notification
 * @see com.btc.micromvc.patterns.command.MacroCommand MacroCommand
 */
public class SimpleCommand extends Notifier implements IControllerCmd
{

	/**
	 * Fulfill the use-case initiated by the given <code>INotification</code>.
	 * 
	 * <P>
	 * In the Command Pattern, an application use-case typically begins with
	 * some user action, which results in an <code>INotification</code> being
	 * broadcast, which is handled by business logic in the <code>execute</code>
	 * method of an <code>IControllerCmd</code>.
	 * </P>
	 * 
	 * @param notification
	 *            the <code>INotification</code> to handle.
	 */
	public void execute( INotification notification )
	{
	}

}
