/*
   microMVC Java Port by Donald Stinchfield <donald.stinchfield@microMVC.org>, et al.
   microMVC - Copyright(c) 2006-08 Futurescale, Inc., Some rights reserved.
   Your reuse is governed by the Creative Commons Attribution 3.0 License
*/

package com.btc.micromvc.patterns.mediator;

import com.btc.micromvc.interfaces.IViewMediator;
import com.btc.micromvc.interfaces.INotification;
import com.btc.micromvc.patterns.observer.Notifier;

/**
 * A base <code>IViewMediator</code> implementation.
 * 
 * @see com.btc.micromvc.core.view.View View
 */
public class ViewMediator extends Notifier implements IViewMediator
{

	/**
	 * The default name of the <code>Mediator</code>.
	 */
	public static final String NAME = "Mediator";
	
	/** 
	 * The name of the <code>Mediator</code>.
	 */
	protected String mediatorName = null;

	/**
	 * The view component
	 */
	protected Object viewComponent = null;

	/**
	 * Constructor.
	 * @param mediatorName
	 * @param viewComponent 
	 */
	public ViewMediator( String mediatorName, Object viewComponent ) {
		this.mediatorName = (mediatorName != null)?mediatorName:NAME; 
		this.viewComponent = viewComponent;	
	}

	/**
	 * Get the name of the <code>Mediator</code>.
	 * 
	 * @return the name
	 */
	public final String getMediatorName( )
	{
		return this.mediatorName;
	}

	/**
	 * Set the <code>IViewMediator</code>'s view component.
	 * 
	 * @param viewComponent
	 */
	public void setViewComponent( Object viewComponent ) 
	{
		this.viewComponent = viewComponent;
	}

	/**
	 * Get the <code>Mediator</code>'s view component.
	 * 
	 * <P>
	 * Additionally, an implicit getter will usually be defined in the subclass
	 * that casts the view object to a type, like this:
	 * </P>
	 * 
	 * <listing> private function get comboBox : mx.controls.ComboBox { return
	 * viewComponent as mx.controls.ComboBox; } </listing>
	 * @return the view component
	 */
	public Object getViewComponent( )
	{
		return this.viewComponent;
	}

	/**
	 * Handle <code>INotification</code>s.
	 * 
	 * <P>
	 * Typically this will be handled in a switch statement, with one 'case'
	 * entry per <code>INotification</code> the <code>Mediator</code> is
	 * interested in.
	 * @param notification 
	 */
	public void handleNotification( INotification notification )
	{
	}

	/**
	 * List the <code>INotification</code> names this <code>Mediator</code>
	 * is interested in being notified of.
	 * 
	 * @return String[] the list of <code>INotification</code> names
	 */
	public String[] listNotificationInterests( )
	{
		return null;
	}
}
