package com.btc.micromvc.patterns.service;

import com.btc.micromvc.interfaces.IModelService;
import com.btc.micromvc.patterns.observer.Notifier;

/**
 * A base <code>IModelService</code> implementation.
 * 
 * <P>
 * In microMVC, <code>ModelService</code> classes are used to manage parts of the
 * application's data model.
 * </P>
 * 
 * <P>
 * A <code>ModelService</code> might simply manage a reference to a local data
 * object, in which case interacting with it might involve setting and getting
 * of its data in synchronous fashion.
 * </P>
 * 
 * <P>
 * <code>ModelService</code> classes are also used to encapsulate the application's
 * interaction with remote services to save or retrieve data, in which case, we
 * adopt an asyncronous idiom; setting data (or calling a method) on the
 * <code>ModelService</code> and listening for a <code>Notification</code> to be
 * sent when the <code>ModelService</code> has retrieved the data from the service.
 * </P>
 * 
 * @see com.btc.micromvc.core.model.Model Model
 */
public class ModelService extends Notifier implements IModelService
{

	// the ModelService name
	private String ModelServiceName = "ModelService";

	// the data object
	private Object data = null;

	/**
	 * Constructor
	 * @param ModelServiceName 
	 * @param data 
	 */
	public ModelService( String ModelServiceName, Object data )
	{
		if (ModelServiceName != null) {
			this.ModelServiceName = ModelServiceName;
		}
		if (data != null) {
			this.data = data;
		}
	}

	/**
	 * Get the ModelService name
	 * @return the ModelService name
	 */
	public String getModelServiceName( )
	{
		return this.ModelServiceName;
	}

	/**
	 * Set the data object
	 * @param data 
	 */
	public void setData( Object data )
	{
		this.data = data;
	}

	/**
	 * Get the data object
	 * @return the data object
	 */
	public Object getData( )
	{
		return this.data;
	}
}
